pyibisami.ami
=============

AMI related submodules in the *PyIBIS-AMI* package.

config
------

.. automodule:: pyibisami.ami.config

model
-----

.. automodule:: pyibisami.ami.model

parameter
---------

.. automodule:: pyibisami.ami.parameter

parser
------

.. automodule:: pyibisami.ami.parser
